Installation
============

Installing earthkit-regrid
----------------------------

Install **earthkit-regrid** with python3 (>= 3.8) and ``pip`` as follows:

.. code-block:: bash

    python3 -m pip install earthkit-regrid
